@@ -1,15 +1,16 @@
 """
 Type annotations for forecastquery service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client/)
 
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_forecastquery import ForecastQueryServiceClient
+    from boto3.session import Session
+    from mypy_boto3_forecastquery.client import ForecastQueryServiceClient
 
-    client: ForecastQueryServiceClient = boto3.client("forecastquery")
+    session = Session()
+    client: ForecastQueryServiceClient = session.client("forecastquery")
     ```
 """
 from typing import Any, Dict, Mapping, Type
@@ -40,8 +41,8 @@ class Exceptions:
 
 class ForecastQueryServiceClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/forecastquery.html#ForecastQueryService.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/forecastquery.html#ForecastQueryService.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client/)
     """
 
     meta: ClientMeta
@@ -50,14 +51,17 @@ class ForecastQueryServiceClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         ForecastQueryServiceClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/forecastquery.html#ForecastQueryService.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client/#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html#can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client/#can_paginate)
         """
 
     def generate_presigned_url(
@@ -70,8 +74,8 @@ class ForecastQueryServiceClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html#generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client/#generate_presigned_url)
         """
 
     def query_forecast(
@@ -86,6 +90,6 @@ class ForecastQueryServiceClient(BaseClient):
         """
         Retrieves a forecast for a single item, filtered by the supplied criteria.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html#query_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client/#query_forecast)
         """
