@@ -1,7 +1,7 @@
 """
 Type annotations for forecastquery service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/type_defs/)
 
 Usage::
 
@@ -14,6 +14,8 @@ Usage::
 import sys
 from typing import Dict, List, Mapping
 
+from typing_extensions import NotRequired
+
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
